#ifndef MSP_GL_TEXUNIT_H_
#define MSP_GL_TEXUNIT_H_

#include <vector>

namespace Msp {
namespace GL {

class TexEnv;
class TexGen;
class Texture;

/**
Keeps track of texture unit related state.  Mostly for internal use.
*/
class TexUnit
{
private:
	unsigned index;
	bool legacy;
	const Texture *texture;
	bool tex_legacy;

	static std::vector<TexUnit> units;
	static TexUnit *cur_unit;

	TexUnit();

public:
	unsigned get_index() const { return index; }
	bool supports_legacy() const { return legacy; }
	bool set_texture(const Texture *, bool = true);
	const Texture *get_texture() const { return texture; }
	bool get_texture_legacy() const { return tex_legacy; }
	void bind();

	static unsigned get_n_units();
	static unsigned get_n_legacy_units();
	static TexUnit &get_unit(unsigned);
	static TexUnit &current();
	static TexUnit *find_unit(const Texture *);
};

} // namespace GL
} // namespace Msp

#endif
